Mutagen
=======

Mutagen is a Python module to handle audio metadata. For more information
visit http://mutagen.readthedocs.org

.. image:: https://travis-ci.org/quodlibet/mutagen.svg?branch=master
    :target: https://travis-ci.org/quodlibet/mutagen
